//~--- JDK imports ------------------------------------------------------------

import java.util.Calendar;
import java.util.logging.Level;
import java.util.logging.Logger;

public class Monitor extends Thread {

    private MeasuringAPI api;
    private EventsHandler evHandler;
    private short measuringPeriod;
    private byte[] monitoredTypes;
    private byte nrParam;
    private Parameter[] params;
    private Timer timers;
    private MeasuringTool tool;
    private boolean toolOrAPI;

    // 1.A.
    public Monitor(short period, boolean toolOrAPI, EventsHandler ev) {
        this.measuringPeriod = period;
        this.toolOrAPI = toolOrAPI;

        if (toolOrAPI) {
            this.tool = new MeasuringTool();
        } else {
            this.api = new MeasuringAPI();
        }
        this.evHandler = ev;
        monitoredTypes = new byte[50];
        params = new Parameter[50];
        nrParam = 0;
        this.start();
    }

    // 2.A.
    public void run() {
        //get instance of Calendar class
        Calendar now;
        while (true) {
            if (nrParam > 0) {
                byte[] types = new byte[nrParam];

                short[] values;

                for (int i = 0; i < nrParam; i++) {
                    types[i] = monitoredTypes[i];
                }

                if (toolOrAPI) {
                    values = tool.measure(types);
                } else {
                    values = api.measure(types);
                }

                for (int i = 0; i < nrParam; i++) {
                    params[i].setValue(values[i]);
                    params[i].checkThresholds();
                }

            }
            try {
                Thread.sleep(measuringPeriod);
            } catch (InterruptedException ex) {
            }
            now = Calendar.getInstance();
            System.out.println("Momentul curent: " 
                    + now.get(Calendar.HOUR_OF_DAY) + ":"
                    + now.get(Calendar.MINUTE) + ":"
                    + now.get(Calendar.SECOND) + ":");
        }

    }

    // 1.B.
    public void addParam(byte type, short interval, short aboveThr, short belowThr) {
        params[nrParam] = new Parameter(type, aboveThr, belowThr, evHandler);

        System.out.println("Monitor.addParam()");

        monitoredTypes[nrParam] = type;

        if (interval > 0) {
            Timer t = new Timer(interval, params[nrParam]);

            t.start();
        }

        nrParam++;
    }

// 2.B.b.
    public short getValue(byte type) {
        short value = 0;

        System.out.println("Monitor.getValue()");
        for (int i = 0; i <
                nrParam; i++) {
            if (type == monitoredTypes[i]) {
                value = params[i].getValue();
            }

        }

        return value;
    }
}


//~ Formatted by Jindent --- http://www.jindent.com
